@@ -66,7 +66,7 @@ static SV*      st_hvref_store( SV* h, const char* key, SV* val );
 static SV*      st_hvref_store_char( SV* h, const char* key, char *val );
 */
 static SV*      st_av_fetch( AV* a, I32 index );
-static IV       st_av_fetch_ptr( AV* a, I32 index );
+static void*    st_av_fetch_ptr( AV* a, I32 index );
 static SV*      st_hv_fetch( HV* h, const char* key );
 static SV*      st_hvref_fetch( SV* h, const char* key );
 /* UNUSED
@@ -86,8 +86,8 @@ static REGEXP*  st_get_regex_from_sv( SV* regex_sv );
 /* UNUSED
 static SV*      st_new_hash_object(const char *class);
 */
-static SV*      st_bless_ptr( const char* class, IV c_ptr );
-static IV       st_extract_ptr( SV* object );
+static SV*      st_bless_ptr( const char* class, void * c_ptr );
+static void*    st_extract_ptr( SV* object );
 static void*    st_malloc(size_t size);
 static void     st_free_token(st_token *tok);
 static void     st_croak(
